#
# spec file for package minitube
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           minitube
Version:        3.9.2
Release:        bp154.1.38
Summary:        Native YouTube Client
License:        GPL-3.0-or-later
Group:          Productivity/Multimedia/Video/Players
URL:            https://flavio.tordini.org/minitube
Source:         %{name}-%{version}.tar.xz
# Manpage written by Jakob Haufe <sur5r@sur5r.net> for the Debian project.
Source1:        minitube.1
# PATCH-FIX-OPENSUSE minitube-no-update-check.patch -- Disable build of internal updater
Patch0:         %{name}-no-update-check.patch
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  libqt5-linguist
BuildRequires:  libqt5-qtdeclarative-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Core) >= 5.12
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Script)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(mpv) >= 0.29.0
Recommends:     %{name}-lang

%description
Minitube is a native YouTube client. With it you can watch YouTube
videos in a new way: you type a keyword, Minitube gives you an
endless video stream.

Minitube is not about cloning the original YouTube web interface,
it strives to create a new TV-like experience.

%lang_package

%prep
%setup -q
%patch0 -p1

# Remove build time references so build-compare can do its work
FAKE_BUILDDATE="$(LC_ALL=C date -u -d "@${SOURCE_DATE_EPOCH}" '+%%b %%e %%Y')"
sed -i "s/__DATE__/\"$FAKE_BUILDDATE\"/" src/aboutview.cpp

%build
%qmake5 \
  PREFIX=%{_prefix}
%make_build

%install
%qmake5_install
install -Dpm 0644 %{SOURCE1} %{buildroot}%{_mandir}/man1/%{name}.1
%suse_update_desktop_file -r %{name} AudioVideo Video Player
# symlink for german translation file de_DE -> de
pushd %{buildroot}%{_datadir}/%{name}/locale
ln -s de_DE.qm de.qm
popd
%fdupes %{buildroot}%{_datadir}/

%files
%license COPYING
%doc AUTHORS CHANGES TODO
%{_bindir}/%{name}
%{_datadir}/%{name}/
%exclude %{_datadir}/%{name}/locale/
%{_datadir}/applications/%{name}.desktop
%dir %{_datadir}/icons/hicolor/*/
%dir %{_datadir}/icons/hicolor/*/apps/
%{_datadir}/icons/hicolor/*/apps/%{name}*
%dir %{_datadir}/metainfo/
%{_datadir}/metainfo/org.tordini.flavio.minitube.metainfo.xml
%{_mandir}/man?/%{name}.?%{?ext_man}

%files lang
%{_datadir}/%{name}/locale/

%changelog
* Fri Nov 12 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to 3.9.2:
  - Update media
  - Load previews sequentially
  - Update js
  - Updated translations
* Tue Sep 14 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to 3.9.1:
  https://github.com/flaviotordini/minitube/compare/3.9...3.9.1
* Wed Jun 23 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 3.9:
  https://github.com/flaviotordini/minitube/compare/3.8.2...3.9
* Sat Apr  3 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 3.8.2:
  - Updated translations
- Update Build Requires - QT >= 5.12 is needed
* Sat Feb 27 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 3.8.1:
  - Fix search by url
  - Updated translations
  - Fix videoIdFromUrl
  - Fix missing name signal
  - Remove json debug
  - Cleanup
* Fri Feb 19 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 3.8:
  - Fix crash
  - Smaller duration font
  - View reworking
  - Import subscriptions
  - Fix related videos thumbs
  - Translations
* Wed Dec 30 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 3.7:
  - Update js
  - Update media
  - Better seeking
  - Remove obsolete code
  - Also parse hours
  - Minor performance fix
  - Remove deprecated sorting
  - Minor cleanup
  - Singlevideosource
  - Emit error if there are no results
  - consolidate yt stuff
  - Fake more videos by loading videos related to the last one
  - Fix crash
* Tue Nov 24 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 3.6.6
  - handle thumb loading error
* Wed Nov 11 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 3.6.5
  - fix deprecated call
* Sun Oct 18 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 3.6.2
  - remove unused functions
* Thu Sep 10 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 3.6.1:
  - Update http
* Tue Aug 18 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 3.5.1:
  - Update README.md
  - Fix build
  - Better server init
  - Update http
  - Better Invidious code
  - Disable yt key warning
- Drop minitube-build-fix.patch. Fixed upstream.
* Sat Aug 15 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 3.5:
  * Minitube uses now the Invidious API. No need to use a Google
    API key anymore.
- Rebase minitube-no-update-check.patch: Disable build of internal
  updater.
- Add minitube-build-fix.patch. See
  https://github.com/flaviotordini/minitube/issues/168
* Thu Jun 11 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 3.4.2:
  * esc closes about view
- Drop minitube-fix_audio_playback.patch, fixed upstream
  https://github.com/flaviotordini/minitube/issues/157
- Drop minitube-fix-for-upstream-missing-qthelper.hpp-in-newer-mpv-version.patch,
  fixed upstream
  https://github.com/flaviotordini/minitube/issues/155
* Sun May 31 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 3.4:
  * 0-9 keyboard shortcuts to navigate video
  * Left and Right arrow keyboard shortcuts to seek 10 seconds
  * New icons
  * Fixed layout bug when window is maximized on macOS
  * Fixed playback for some videos
  * Updated Polish and Japanese translations
- Run spec-cleaner
- Rebase minitube-no-update-check.patch,
  minitube-qt5-lessthan-ten.patch and
  minitube-fix-for-upstream-missing-qthelper.hpp-in-newer-mpv-version.patch
- Add minitube-fix_audio_playback.patch
* Wed Mar 18 2020 Carsten Ziepke <kieltux@gmail.com>
- Added fix for building with newer mpv versions:
  minitube-fix-for-upstream-missing-qthelper.hpp-in-newer-mpv-version.patch
  The qthelper.hpp header file is removed in the git version of mpv
  because it is depreceated
- Fix german translation (symlink DE_de -> de).
* Sun Feb  2 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 3.3:
  * Fix video playback
  * Updated translations
  * Change user agent from curl to Mozilla
* Thu Dec  5 2019 Carsten Ziepke <kieltux@gmail.com>
- Update to version 3.2:
  * Updated translations
  * Fixes to video playback
  * Qt >= 5.10 is needed
- Removed minitube.changes as source to use as reference for the
  fake build date, because SOURCE_DATE_EPOCH is used
- Spec cleanup
* Sun Jun 16 2019 Carsten Ziepke <kieltux@gmail.com>
- Update to version 3.1:
  * Fixes some videos skipping.
  * Bug fix for audio playback not resuming after long pauses.
* Wed May  8 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 3.0:
  * Port from Phonon to MPV.
  * Support all YouTube video resolutions up to 4K.
- Switch to SOURCE_DATE_EPOCH for fake build dates.
* Wed Jan  3 2018 aloisio@gmx.com
- Update to version 2.9
  * Menu bar is now hidden by default
  * New Chrome-like toolbar menu that contains actions not
    available in the rest of the UI.
  * A bit of code refactoring and cleanup, using more C++11
    features. Minitube uses a little less memory and should be
    slightly faster now.
  * Usual slew of minor fixes and visual tweaks.
- Added minitube.changes as source to use as reference for the
  fake build date.
* Sun Nov  5 2017 michael@stroeder.com
- Update to 2.8
  * Improving the overall quality of the application by
    fixing small bugs and defects
* Wed May 31 2017 kieltux@gmail.com
- Update to 2.7
  * Show toolbar only in "media view"
  * Don't draw channel in playlist when all videos from same channel
  * Use system proxies
  * Ability to hide menu on Windows and Linux
  * Use system icons on Linux
  * Remove slider custom style on Windows and Linux
  * Long press on stop toolbar button to show
    "Stop After This" menu on Windows and Linux
  * Style tweaks
  * Fix sidebar resizing on Mac
  * Fix floating garbage on fullscreen on Mac
  * Fix painting issues in "search view" on Linux
  * Updated translations
- Removed obsolete appdata.patch (fixed upstream
  https://github.com/flaviotordini/minitube/pull/52)
* Sat Feb 11 2017 kieltux@gmail.com
- Update to 2.6
  * solves an issue with VEVO videos
  * New "Restricted Mode" that blocks inappropriate content
- Removed obsolete minitube-fix-watchrelatedvideo-icon.patch
* Sun Sep 18 2016 mailaender@opensuse.org
- Add appdata.patch for https://en.opensuse.org/openSUSE:AppStore
* Sun Jan 24 2016 kieltux@gmail.com
- update to 2.5.2
  * solves an issue with VEVO videos
* Sun Nov 22 2015 mailaender@opensuse.org
- update to 2.5.1
  * solves an issue with VEVO videos
* Sat Oct 31 2015 sor.alexei@meowr.ru
- Update to 2.5:
  * Use Qt5 instead of Qt4.
  * HiDPI support.
  * Mac style overhaul: new toolbar, lighter fonts & tabs.
  * Status Bar hidden when not needed: less clutter, more room for
    videos.
  * Clickable links in video description.
  * Autoadjust window size.
  * Smart date formatting: 3 hours ago, 1 month ago, etc.
  * When opening the YouTube webpage the video now starts from
    where it left in Minitube.
  * Fix videos restarting after long pause.
  * New and updated translations.
- Use Qt5 instead of Qt4.
* Sat Jun  6 2015 mailaender@opensuse.org
- Add a Google API Key (boo#933004)
* Sun Apr 19 2015 sor.alexei@meowr.ru
- Update to 2.4:
  * Use YouTube APIs version 3.
  * Use HTTPS everywhere for better privacy and security.
  * Automatically load more videos in the playlist for less clicking.
  * Fix subscriptions sorting.
  * Fix toolbar style.
  * Add and update translations.
- Rebase minitube-no-update-check.patch.
* Sat Feb 28 2015 sor.alexei@meowr.ru
- Update to 2.3.1:
  * Ensure JS reloading for new version.
  * Remove unused code, added js ageGate.
  * Fix VEVO videos.
  * Restore wheel scroll setting.
- Remove qtlocalpeer.patch: fixed upstream.
- Spec cleanup.
- Rename disable_update_check.patch to
  minitube-no-update-check.patch.
- Rename missing_watchrelatedvideo_icon.patch to
  minitube-fix-watchrelatedvideo-icon.patch.
- Add minitube-lang package.
* Wed Nov  5 2014 kieltux@gmail.com
- Patch for missing toolbar icon (watch related videos)
  + missing_watchrelatedvideo_icon.patch
* Wed Nov  5 2014 kieltux@gmail.com
- Update to 2.3
  * Take video snapshots at full resolution
  * Faster and more reliable seeking
  * Faster video start with longer videos
  * Slide transition in playlist navigation
  * Make the volume handle red when volume is zero
  * Enhancements to the search suggestions
  * New and updated translations
- Removed patch to inihibit screensaver
- Added manpage written by Jakob Haufe for the Debian project
* Mon Aug  4 2014 kieltux@gmail.com
- update to 2.2
  * Subscriptions context menu: Unsubscribe, Mark as Watched
  * Added --stop-after-this command line switch
  * Added Stop After This Video Unity & Gnome 3 action
  * Fixed painting errors when scrolling playlist on Linux
  * Fixed bug with dragging playlist items from the thumbnail
  * Fixed some videos not playing
  * Updated translations
- added patch for disable update check
* Fri Feb  7 2014 kieltux@gmail.com
- update to 2.1.6
  * Fix some videos not playing
  * Remove obsolete categories in the Browse tab
- removed now unneeded patch for missing locale files
* Sat Dec 28 2013 kieltux@gmail.com
- fix for missing locale files in source package
- update to 2.1.5
  * Fix some videos not playing
  * Show video title on hover when playlist is in minimode (thumbs only)
  * Lighter font for video title and description on Mac & Ubuntu
  * Fixed fonts in Mac OS X Mavericks
  * Fixed "busy" mouse cursor at launch on Ubuntu
  * Updated translations
* Fri Oct 11 2013 kieltux@gmail.com
  * included patch to inihibt screensaver during playback from
    https://launchpadlibrarian.net/105980691/inhibit-screensaver-during-playback
- update to 2.1.3
  * Downloads only enabled on Creative Commons licensed videos
  * Fixed playback of some videos
  * Fixed VEVO videos playback
  * Fixed Ubuntu skin not being used
  * Channel subscriptions
  * Move window by dragging from inside the video area
  * Faster startup
  * Optimizations and tweaks to the playlist
  * Float on top icon was missing on Mac & Windows
  * Compact mode window fixed aspect ratio on Mac
  * Ubuntu notifications
  * Fixed skipping to the next video
  * Fixed compact mode video cropped with very small window
  * Fixed long words or URLs in the video description causing a window resize
  * Fixed crash when resizing the playlist to a very small width
* Wed Feb 27 2013 mvyskocil@opensuse.org
- update to 2.0
  * YouTube categories and "standard feeds": "Most Popular", "Featured", etc
  * Country selection for YouTube categories and feeds
  * Autoupdate on Mac and Windows
  * Related videos are now appended to the video when pasting a YouTube link
  * "Show 10 More" with a single click
  * Play video in the playlist with a single click on its thumbnail
  * OS X Mountain Lion notifications on video start
  * Fixed some YouTube links not working when pasted in the searchbox
  * Fixed playlist drag'n'drop
  * Fixed system language settings detection
  * Fixed clicking on channel names not working in some cases
  * Fixed incorrect number of downloads in status bar
* Tue Oct  2 2012 mailaender@opensuse.org
- updated to 1.9.0
  * Adapted to YouTube changes
  * New search filter UI. Filter results by publication date, video duration and video quality.
  * Sort by rating
  * Search spell suggestions: “Did you mean…”
  * New downloads are now added at the top of the list
  * Video definition indicator while downloading videos
  * Simple integration with Buffer app
  * Better fullscreen experience on the Mac: sidebar shows when the mouse hits the left side, mouse and playlist autohide
  * Compatible with OS X Mountain Lion Gatekeeper
  * Partial Retina Display support. Still using 1x bitmaps because of Qt not being ready
  * OS X Mountain Lion notifications when a download finishes
  * Fixed flickering in fullscreen controls on Linux, also playlist and toolbar now autohide
  * New and updated translations. Thanks to all the translators involved!
* Thu Aug 23 2012 mailaender@opensuse.org
- updated to 1.8.0
  * Enhanced Compact Mode: window on top, can be made smaller and remembers its own position
  * Adaptive video title font size
  * Unity & GNOME 3 actions (aka Quicklists)
  * Mac Sandbox support
  * Added missing menu item to restore hidden window, as per the OS X HIG
  * More responsive UI while loading videos on the Mac
  * Selecting a recent keyword now also sets the searchbox text
  * Selecting a suggestion now also sets the searchbox text on the Mac
  * Fixed duplicate channel names in suggestions popup
  * Fixed playback not starting or being interrupted on Linux
  * Fixed search box being erroneously focused on the Mac
  * Fixed wrong localization of some menu items on the Mac
* Sat Mar 10 2012 mailaender@opensuse.org
- updated to 1.7.1
  * Fixed searching YouTube videos ids containing the “-” sign
  * Fixed search auto-completion popup appearing when not needed
  * Fixed temporary files not being deleted on Windows
  * Fixed quitting from the Dock on the Mac
  * Fixed bug preventing system shutdown on the Mac
  * Fixed search box selecting text while typing and losing focus on ESC key on the Mac
  * On the Mac, “Quit” and other application menu items are now correctly localized
* Wed Aug 10 2011 buschmann23@opensuse.org
- updated to 1.5
  * Works again after YouTube changes
  * Drag'n'drop YouTube URLs to Minitube window
  * When pasting YouTube URLs, Minitube now correctly plays videos
  * New and updated translations
* Mon May 30 2011 prusnak@opensuse.org
- updated to 1.3.4
* Fri Mar  4 2011 buschmann23@opensuse.org
- updated to version 1.4
  + YouTube channel search
  + Fixed many playback issues
  + Progress bar when loading a video
  + Command line search
  + Partially restored seeking on Linux
* Sat Dec 18 2010 bitshuffler@opensuse.org
- Updated to 1.3
  - Minitube works again!
  - Big internal changes in how playback works, seeking is now disabled on Linux
  - Brand new icon designed by David Nel
  - Using Qt/Cocoa on the Mac, now requiring Leopard or better
  - New Macedonian translation by Veta Branislav
  - Updated Finnish translation
  - New german translation by Jakob Kramer
* Wed Oct 13 2010 adam@mizerski.pl
- update to 1.2
  - Ability to download videos
  - Support for media keys on GNOME
  - More style, especially on the Mac
  - Fixed crash when trying delete or move the the las playlist item
* Fri May 28 2010 adam@mizerski.pl
- added Requires: phonon
* Tue May 25 2010 adam@mizerski.pl
- updated to 1.0
  - Ability to play Full HD (1080p) videos
  - Ability to copy the YouTube link and the video stream URL to the clipboard
  - Fixed videos failing to play
  - Fixed missing caret in the search box
  - Better toolbar and icon theme integration on Linux with Qt >= 4.6
  - Completely removed tooltips
  - Romanian translation by Ovidiu Niţan
  - Greek translation by Giorgos Skettos
  - Dutch translation by Brian Keetman
  - Arabic translation by Sderawi
  - Portuguese translation by Daniel Rodrigues
  - Finnish translation by Jesse Jaara
  - Bulgarian translation by Tsvyatko Makazchiev
* Sun Jan 24 2010 prusnak@suse.cz - 0.9
- updated to 0.9
* Thu Dec 24 2009 prusnak@suse.cz - 0.8.1
- merged packages from openSUSE:Factory:Contrib and KDE:KDE4:Community
* Sat Nov 21 2009 tittiatcoke@gmail.com - 0.8.1
- Update to version 0.8.1
  - Fix showstopper bug: Normal quality videos won't play when HD mode
    is enabled
  - Turkish translation by Ali E. İmrek
* Thu Nov 19 2009 buschmann23@opensuse.org - 0.8
- fixed file list
* Tue Nov 17 2009 tittiatcoke@gmail.com - 0.8
- updated to version 0.8
  * HD video support
  * Volume level and mute is restored accross sessions
  * No icons in menus on Linux (GNOME 2.28 style)
  * Select search box text on Ctrl+F
  * Handle HTTP_PROXY variable with trailing slash (Fix by Eduardo Suarez-Santana)
  * Croatian translation by Srecko Belaic
  * Latvian translation by Inga Muste
  * Galician and Neutral Spanish translations by Miguel Anxo Bouzada
  * Hungarian translation by Krisztián Horváth
  * French translation by Guillaume Betous
* Mon Oct 12 2009 buschmann23@opensuse.org - 0.7
- updated to version 0.7
  + Fixed "embedding disabled by request" message. All videos now play.
  + Slightly faster playlist painting
  + Fixed overflowing text in the playlist
  + Fixed view crossfades on the Mac
  + Fixed FreeDesktop icons on Linux
* Tue Sep 15 2009 buschmann23@opensuse.org - 0.6.1
- updated to version 0.6.1
  + Fixed showstopper bug caused by a change in the YouTube web
    service. Thanks to Guillaume Girard for reporting it.
* Mon Sep  7 2009 buschmann23@opensuse.org - 0.6
- initial package
- version 0.6
